cloudos.query_results: Fetch Async Query Results

View source: R/query.R

cloudos.query_resultsR Documentation

Fetch Async Query Results

Description

Fetches results from a completed async SQL task and returns as a dataframe.

Usage

cloudos.query_results(profilename = "", task_id = "")

Arguments

profilename

Character. Name of the configured profile to use. If empty or NULL, uses the default profile.

task_id

Character. Task ID returned from cloudos.query_submit_async().

Details

Note: Pagination is controlled when submitting the query via cloudos.query_submit_async(), not when fetching results. This function returns whatever page the task was configured for.

Value

Data frame with query results from the page configured at submission time.

Examples

## Not run: 
  # Fetch results for a task (returns the page configured when query was submitted)
  results <- cloudos.query_results(
    profilename = "production",
    task_id = "69a5c58d626fe626da0025ce"
  )

## End(Not run)

cloudosR documentation built on June 1, 2026, 5:07 p.m.