cloudos.query_status: Check Async Query Status

View source: R/query.R

cloudos.query_statusR Documentation

Check Async Query Status

Description

Returns the current status and metadata for a submitted async SQL task.

Usage

cloudos.query_status(profilename = "", task_id = "")

Arguments

profilename

Character. Name of the configured profile to use. If empty or NULL, uses the default profile.

task_id

Character. Task ID returned from cloudos.query_submit_async().

Value

List with task status, count of results, and other metadata.

Examples

## Not run: 
  status <- cloudos.query_status(
    profilename = "production",
    task_id = "69a5c58d626fe626da0025ce"
  )
  print(status$status)
  print(status$count_of_results)

## End(Not run)

cloudosR documentation built on June 1, 2026, 5:07 p.m.