| cloudos.profile_list | R Documentation |
Lists configured profiles so users can confirm available environments.
cloudos.profile_list()
Data frame with profile names and metadata (workspace_id, default, created_at, updated_at). Returns empty data frame if no profiles are configured.
## Not run:
profiles <- cloudos.profile_list()
print(profiles)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.