| cloudos.query_results | R Documentation |
Fetches results from a completed async SQL task and returns as a dataframe.
cloudos.query_results(profilename = "", task_id = "")
profilename |
Character. Name of the configured profile to use. If empty or NULL, uses the default profile. |
task_id |
Character. Task ID returned from cloudos.query_submit_async(). |
Note: Pagination is controlled when submitting the query via cloudos.query_submit_async(), not when fetching results. This function returns whatever page the task was configured for.
Data frame with query results from the page configured at submission time.
## Not run:
# Fetch results for a task (returns the page configured when query was submitted)
results <- cloudos.query_results(
profilename = "production",
task_id = "69a5c58d626fe626da0025ce"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.