| cloudos.query_status | R Documentation |
Returns the current status and metadata for a submitted async SQL task.
cloudos.query_status(profilename = "", task_id = "")
profilename |
Character. Name of the configured profile to use. If empty or NULL, uses the default profile. |
task_id |
Character. Task ID returned from cloudos.query_submit_async(). |
List with task status, count of results, and other metadata.
## Not run:
status <- cloudos.query_status(
profilename = "production",
task_id = "69a5c58d626fe626da0025ce"
)
print(status$status)
print(status$count_of_results)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.